==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/vpn_connection/VpnConnectionTunnel1LogOptions.java <==
package com.hashicorp.cdktf.providers.aws.vpn_connection;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:56.036Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.vpnConnection.VpnConnectionTunnel1LogOptions")
@software.amazon.jsii.Jsii.Proxy(VpnConnectionTunnel1LogOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VpnConnectionTunnel1LogOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * cloudwatch_log_options block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions getCloudwatchLogOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<VpnConnectionTunnel1LogOptions> {
        com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions;

        /**
         * Sets the value of {@link VpnConnectionTunnel1LogOptions#getCloudwatchLogOptions}
         * @param cloudwatchLogOptions cloudwatch_log_options block.
         *                             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudwatchLogOptions(com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions) {
            this.cloudwatchLogOptions = cloudwatchLogOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpnConnectionTunnel1LogOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public VpnConnectionTunnel1LogOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VpnConnectionTunnel1LogOptions {
        private final com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudwatchLogOptions = software.amazon.jsii.Kernel.get(this, "cloudwatchLogOptions", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudwatchLogOptions = builder.cloudwatchLogOptions;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions getCloudwatchLogOptions() {
            return this.cloudwatchLogOptions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudwatchLogOptions() != null) {
                data.set("cloudwatchLogOptions", om.valueToTree(this.getCloudwatchLogOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.vpnConnection.VpnConnectionTunnel1LogOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VpnConnectionTunnel1LogOptions.Jsii$Proxy that = (VpnConnectionTunnel1LogOptions.Jsii$Proxy) o;

            return this.cloudwatchLogOptions != null ? this.cloudwatchLogOptions.equals(that.cloudwatchLogOptions) : that.cloudwatchLogOptions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudwatchLogOptions != null ? this.cloudwatchLogOptions.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/vpn_connection/VpnConnectionTunnel1LogOptions.java <==
package com.hashicorp.cdktf.providers.aws.vpn_connection;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.126Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.vpnConnection.VpnConnectionTunnel1LogOptions")
@software.amazon.jsii.Jsii.Proxy(VpnConnectionTunnel1LogOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VpnConnectionTunnel1LogOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * cloudwatch_log_options block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions getCloudwatchLogOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<VpnConnectionTunnel1LogOptions> {
        com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions;

        /**
         * Sets the value of {@link VpnConnectionTunnel1LogOptions#getCloudwatchLogOptions}
         * @param cloudwatchLogOptions cloudwatch_log_options block.
         *                             Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudwatchLogOptions(com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions) {
            this.cloudwatchLogOptions = cloudwatchLogOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VpnConnectionTunnel1LogOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public VpnConnectionTunnel1LogOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VpnConnectionTunnel1LogOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VpnConnectionTunnel1LogOptions {
        private final com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions cloudwatchLogOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudwatchLogOptions = software.amazon.jsii.Kernel.get(this, "cloudwatchLogOptions", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudwatchLogOptions = builder.cloudwatchLogOptions;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.vpn_connection.VpnConnectionTunnel1LogOptionsCloudwatchLogOptions getCloudwatchLogOptions() {
            return this.cloudwatchLogOptions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudwatchLogOptions() != null) {
                data.set("cloudwatchLogOptions", om.valueToTree(this.getCloudwatchLogOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.vpnConnection.VpnConnectionTunnel1LogOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VpnConnectionTunnel1LogOptions.Jsii$Proxy that = (VpnConnectionTunnel1LogOptions.Jsii$Proxy) o;

            return this.cloudwatchLogOptions != null ? this.cloudwatchLogOptions.equals(that.cloudwatchLogOptions) : that.cloudwatchLogOptions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudwatchLogOptions != null ? this.cloudwatchLogOptions.hashCode() : 0;
            return result;
        }
    }
}
